@@ -15,13 +15,13 @@ plot(regions1, main = "regions1")
 plot(regions2, main = "regions2")
 
 ## ------------------------------------------------------------------------
-regions_vm = vmeasure_calc(regions1, z, regions2, z)
+regions_vm = vmeasure_calc(x = regions1, y = regions2, x_name = z, y_name = z)
 regions_vm
 
 ## ---- warning=FALSE, fig.height=2, fig.height=4, out.width="45%", echo=FALSE----
 plot(regions_vm$map1["rih"], main = "Map1: rih"); plot(regions_vm$map2["rih"], main = "Map2: rih")
 
 ## ------------------------------------------------------------------------
-regions_mc = mapcurves_calc(regions1, z, regions2, z)
+regions_mc = mapcurves_calc(x = regions1, y = regions2, x_name = z, y_name = z)
 regions_mc
 
