@@ -2,11 +2,10 @@ context("test-eco-us.R")
 data("eco_us")
 vm  = vmeasure_calc(eco_us, eco_us, PROVINCE, SECTION)
 vm2 = vmeasure_calc(eco_us, eco_us, DOMAIN, DIVISION)
-# vm2 = vmeasure_calc(eco_us, DOMAIN, eco_us, PROVINCE)
-# vm3 = vmeasure_calc(eco_us, DOMAIN, eco_us, SECTION)
-# vm4 = vmeasure_calc(eco_us, DIVISION, eco_us, PROVINCE)
-# vm5 = vmeasure_calc(eco_us, DIVISION, eco_us, SECTION)
-# vm6 = vmeasure_calc(eco_us, PROVINCE, eco_us, SECTION)
+vm3 = vmeasure_calc(eco_us, eco_us, DOMAIN, SECTION)
+vm4 = vmeasure_calc(eco_us, eco_us, DIVISION, PROVINCE)
+vm5 = vmeasure_calc(eco_us, eco_us, DIVISION, SECTION)
+vm6 = vmeasure_calc(eco_us, eco_us, PROVINCE, SECTION)
 mc = mapcurves_calc(eco_us, eco_us, PROVINCE, SECTION)
 
 test_that("sabre works on vector", {
